# Pygame Grid

This module provides a function to draw a grid on the active pygame screen to make placing things easier.

This is a work in progress and will be updated with more details in the future.